.. _api_reference:

*************
API Reference
*************

.. module:: lollipop

Types
=====

.. automodule:: lollipop.types
    :members:

Validators
==========

.. automodule:: lollipop.validators
    :members:

Errors
======

.. automodule:: lollipop.errors
    :members:
